package org.dromara.zhishu.mapper;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.dromara.common.mybatis.core.mapper.BaseMapperPlus;
import org.dromara.zhishu.domain.NewUserInfo;
import org.dromara.zhishu.domain.vo.NewUserVo;

@Mapper
public interface NewUserBoMapper extends BaseMapperPlus<NewUserInfo, NewUserVo> {


    void insertAudit(@Param("userId") Long userId);

    Integer selectAudit(Long userId);

    Long selectId(Long userId);

    void updatePhone(String email, String contactPhone, Long userId);

    Integer insertAuditInfo(NewUserInfo add);

    Integer selectByPhone(String contactPhone);
}
